# Minimal-ActivityPub

[![Repo](https://img.shields.io/badge/repo-Codeberg.org-blue)](https://codeberg.org/MarvinsMastodonTools/minimal-activitypub "Repo at Codeberg.org")
[![CI](https://ci.codeberg.org/api/badges/MarvinsMastodonTools/minimal-activitypub/status.svg)](https://ci.codeberg.org/MarvinsMastodonTools/minimal-activitypub "CI / Woodpecker")
[![Downloads](https://pepy.tech/badge/minimal-activitypub)](https://pepy.tech/project/minimal-activitypub "Download count")
[![pip-audit](https://img.shields.io/badge/pip--audit-checked-green)](https://pypi.org/project/pip-audit/ "Checked with pip-audit")
[![CodeLimit](https://img.shields.io/badge/CodeLimit-checked-green.svg)](https://github.com/getcodelimit/codelimit "Checked with CodeLimit")
[![Codestyle](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black "Code style: black")
[![Version](https://img.shields.io/pypi/pyversions/minimal-activitypub)](https://pypi.org/project/minimal-activitypub "PyPI – Python Version")
[![Wheel](https://img.shields.io/pypi/wheel/minimal-activitypub)](https://pypi.org/project/minimal-activitypub "PyPI – Wheel")
[![AGPL](https://www.gnu.org/graphics/agplv3-with-text-162x68.png)](https://codeberg.org/MarvinsMastodonTools/minimal-activitypub/src/branch/main/LICENSE.md "AGPL 3 or later")

Minimal-ActivityPub is a minimal Python implementation of the ActivityPub REST API used by [Mastodon](https://joinmastodon.org/), [Pleroma](https://pleroma.social/), and [Takahe](https://jointakahe.org/). This implementation makes use of asyncio where appropriate. It is intended to be used as a library by other applications. No standalone functionality is provided.

Minimal refers to the fact that only API calls I need for my other projects [Fedinesia](https://codeberg.org/MarvinsMastodonTools/fedinesia), [Lemmy2Fedi](https://codeberg.org/MarvinsMastodonTools/lemmy2fedi) and [Tootbot](https://codeberg.org/MarvinsMastodonTools/tootbot) are implemented.

**DO NOT** expect a full or complete implementation of all [ActivityPub API](https://activitypub.rocks/) functionality.

For more details have a look at the [Documentation](https://marvinsmastodontools.codeberg.page/minimal-activitypub/).

## Contributing

Issues and pull requests are welcome.

Minimal-ActivityPub is using [pre-commit](https://pre-commit.com/) and [rye](https://rye-up.com/). Please install and use both pre-commit and rye if you'd like to contribute.

## Licensing

Minimal-ActivityPub is licenced with the [GNU Affero General Public License v3.0](http://www.gnu.org/licenses/agpl-3.0.html)

## Supporting Minimal-ActivityPub

There are a number of ways you can support Minimal-ActivityPub:

- Create an issue with problems or ideas you have with/for Minimal-ActivityPub
- You can [buy me a coffee](https://www.buymeacoffee.com/marvin8).
- You can send me small change in Monero to the address below:

### Monero donation address
`8ADQkCya3orL178dADn4bnKuF1JuVGEG97HPRgmXgmZ2cZFSkWU9M2v7BssEGeTRNN2V5p6bSyHa83nrdu1XffDX3cnjKVu`
